#!/usr/bin/perl -w
#
# crontabber.pl - processes crontab.master to produce new crontab files(s)
#
# See crontab.master for file format.
#
# Steve Traugott - Wed May  8 19:40:38 EDT 1996
# Matt Nordling  - Mon Nov 12 19:06:10 PST 2001
#   Added random, mod_hostname and mod_inet feature
#
#   Copyright (C) 2001  Steve Traugott, http://www.stevegt.com
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

$| = 1;
#use strict;

my $MASTER="/etc/crontab.master";
my $STAMP_FILE="/var/isconf/.crontabber";
my $MASTER_TIME = (stat($MASTER))[9];
my $STAMP_TIME = (stat($STAMP_FILE))[9] || -1;

if ($MASTER_TIME > $STAMP_TIME) {
  `touch $STAMP_FILE`;
  my $rc = $? >> 8;
  warn "$0: Error updating stamp file $STAMP_FILE\n" if $rc;
} else {
  print "$0: Nothing to do - exiting\n";
  exit 0;
}

chomp(my $hostname=`hostname`);
my $domainname = `grep ^domain /etc/resolv.conf`; 
$domainname =~ s/^domain\s+//;
$domainname =~ s/\s+$//;         # EWWWW

open(MASTER, "<$MASTER") || die "$MASTER not found";

while (<MASTER>) {
  chomp;
  s/^#.*//;
  s/^\s+//;
  s/\s+$//;
  next unless length;

  my ($user, $locale, $cronline) = split(":");

  if ($locale eq $hostname || $locale eq $domainname || $locale eq "all" ) {
    `lsuser $user >/dev/null 2>&1`;
    my $rc = $? >> 8;
    warn "  Error: $user does not exist. Skipping...\n" if $rc;
    next if $rc;

    $cronline =~ s/<\s*RANDOM\s+(\d+)\s*.\s*(\d+)\s*>/random($1, $2)/egi;
    $cronline =~ s/<\s*MOD_INET\s+(\d+)\s*.\s*(\d+)\s*>/mod_inet($1, $2)/egi;
    $cronline =~ s/<\s*MOD_IS_HOSTNAME\s+(\d+)\s*.\s*(\d+)\s*>/mod_hostname($1, $2)/egi;
    if ($cronline =~ /<\s*\S+\s*\d+\s*,\s*\d+\s*>/g) {
      $cronline = "# " . $cronline;
    }


    # yep - write it
    if (eof($user)) {

      print "opening $user\n";
      open($user, "| EDITOR='cat >' su $user -c '/usr/bin/crontab -e'")
	|| die;
      chomp(my $now=`date`);
      print $user "#
# $user crontab for $hostname 
#
# THIS FILE IS AUTOMATICALLY GENERATED BY:
#	$0
#
# DO NOT EDIT THIS FILE!!!  If you do, your changes will be 
# overwritten.  
#
# The master copy of this file is:
#
#	$MASTER
#
# This file is distributed through rsync - figure out where the master 
# really lives or else your life will be quite miserable
#
# Generated $now
#
";
    }
    print $user "$cronline\n";
  }
}

sub random {
  my $MIN = shift;
  my $MAX = shift; $MAX++;

  my $random = int (rand ($MAX - $MIN)) + $MIN;
  return ($random);
}

sub mod_inet {
  my $MIN = shift;
  my $MAX = shift;

  my @addr = (split /\s+/, `ifconfig -a | grep inet | head -1 | tr '.' ' '`);
  my $result = ($addr[5]) % ($MAX - $MIN) + $MIN;
  return ($result);
}

sub mod_hostname {
  my $MIN = shift;
  my $MAX = shift;
  my $letter = 0;
  my $sum = 0;

  my @hostname = unpack ("C*", $hostname);
  foreach $letter (@hostname) {
    $sum+=$letter;
  }
  my $result = $sum % ($MAX - $MIN) + $MIN;
  return $result;
}
