# expandvars.pl
#
# usage: perl -w expandvars.pl var1=foo var2=bar < vars.conf
# 
# ...will return the string "var3=bing var4=bang var5=bong" if
# vars.conf is the example shown below.
#
# Given a list of tuples, will expand the tuple values into a string
# (usually more tuples, but doesn't have to be).  The expansion is
# determined by a configuration file fed in via stdin.
#
# Example vars.conf:
#
# var1=foo: var3=bing var4=bang
# var2=bar: var5=bong 
# var2=baz: var5=briggle
#
#
#   Copyright (C) 2001  Steve Traugott, http://www.stevegt.com
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

my %conf;
my $key;
while(<STDIN>)
{
  chomp;
  /^(\S+):(.*)/ && do
  {
    $key=$1;
    $conf{$key}=$2;
    next;
  };

  $conf{$key}="$conf{$key} $_" if $conf{$key};
}


for(@ARGV)
{
  /^(\w+=\S+)$/ && do 
  {
    print "$conf{$_} " if $conf{$_};
    next;
  };

  die "syntax error in hosts.conf in '@ARGV' near '$_'\n";
}


