# $Id: hp-ux.mk,v 1.1 2003/07/25 00:46:09 loosifer Exp $
#
#	THIS MAKEFILE MUST BE EXECUTED ON THE TARGET MACHINE ( the machine
#	which is to be configured/updated).
#
#  This makefiles is used by $IS_ROOTDIR/bin/isconf to build and configure
#  a system.

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
#
# the first lines are the macro definitions, which will
# all be called with the same stanzas, all defined below
#
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# Install packages
# the data format is 'pkg/<package>--<version>--<vendor>' OR
# 'pkg/<package>__<version>__<vendor>' 
# the pkginstall accepts either '__' or '--' as
# separators
#

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
#
# now all individual stanzas
#
#------------------------------------------------------------------------#

###
# all platform-specific makefiles must have a reboot stanza
reboot:
	if [ "X$(CONTEXT)" != "XBOOT" ]; then \
		echo CONTEXT is $(CONTEXT); \
		echo You can only reboot in boot context; \
		exit 1; \
	fi
	@echo "rebooting from make"
	- rm -f .reboot_needed
	/var/isconf/lib/targets/hp-ux/shutdown

install:
	- ln -s ../init.d/isconf /sbin/rc2.d/S999isconf
	stamp $@

makelink:
	ln -s /usr/local/bin/gmake /usr/local/bin/make
	stamp $@

# so we don't have to have so many stanzas in types
filesystems/isconf: filesystems/new__boot__isconf__10000__isconf
	stamp $@;

keeprebooting: reboot

oracle_user:
	systemuser.sh oracle 555 dba 102 /usr/bin/ksh /home/oracle "Oracle Account"
	stamp $@

vncserver-install-3.3.3r2: vncserver-install-3.3.3r2-rc vncserver-install-3.3.3r2-config vncserver-install-3.3.3r2-links vncserver-install-3.3.3r2-pass

vncserver-install-3.3.3r2-rc:
	cp /usr/local/install/vncserver/3.3.3r2/etc/vncserver /sbin/init.d
	ln -s /sbin/init.d/vncserver /sbin/rc2.d/S500vncserver
	ln -s /sbin/init.d/vncserver /sbin/rc0.d/S100vncserver
	stamp $@

vncserver-install-3.3.3r2-config:
	echo 'VNCSERVER=1' > /etc/rc.config.d/vncserver
	stamp $@

vncserver-install-3.3.3r2-links:
	for each in /usr/local/install/vncserver/3.3.3r2/bin/*; do \
		ln -s $$each /usr/local/sbin/; done
	stamp $@

vncserver-install-3.3.3r2-pass:
	mkdir -p ~genesis/.vnc
	cp /usr/local/install/vncserver/3.3.3r2/etc/passwd ~genesis/.vnc/passwd
	chown -R genesis ~genesis/.vnc
	chmod 400 ~genesis/.vnc/passwd
	stamp $@

nologin-sshd:
	cp /usr/local/etc/sshd_config /usr/local/etc/sshd_config.bak
	sed '/UseLogin/s/^..*/UseLogin no/' /usr/local/etc/sshd_config.bak > /usr/local/etc/sshd_config
	trigger /usr/local/etc/sshd_config
	stamp $@

5passwd-tries:
	if [ -d "/tcb" ]; then \
		/usr/lbin/modprdef -m usrpick=YES,rstrpw=NO,nullpw=NO,syspnpw=YES,syschpw=NO,sysltpw=YES,bootpw=NO,mintm=0,lftm=196,exptm=90,expwarn=7,umaxlntr=5,llog=-1,tmaxlntr=10,dlylntr=2,lntmout=0,maxpwln=8; \
	fi
	stamp $@

90day-password:
	if [ -d "/tcb" ]; then \
	/usr/lbin/modprdef -m usrpick=YES,rstrpw=NO,nullpw=NO,syspnpw=YES,syschpw=NO,sysltpw=YES,bootpw=NO,mintm=0,lftm=196,exptm=90,expwarn=7,umaxlntr=3,llog=-1,tmaxlntr=10,dlylntr=2,lntmout=0,maxpwln=8; \
	fi
	stamp $@

chmoddepot: depotdirchmod depotfilechmod

depotdirchmod:
	find /var/depot -type d -exec chmod 755 {} \; -print
	stamp $@

depotfilechmod:
	find /var/depot -type f -exec chown 755 {} \; -print
	stamp $@

nfsserver:
	cp /etc/rc.config.d/nfsconf /etc/rc.config.d/nfsconf.bak
	echo "NFS_CLIENT=1" > /etc/rc.config.d/nfsconf
	echo "NFS_SERVER=1" >> /etc/rc.config.d/nfsconf
	echo "NUM_NFSD=4" >> /etc/rc.config.d/nfsconf
	echo "NUM_NFSIOD=4" >> /etc/rc.config.d/nfsconf
	echo "AUTOMOUNT=0" >> /etc/rc.config.d/nfsconf
	echo "START_MOUNTD=1" >> /etc/rc.config.d/nfsconf
	trigger /etc/rc.config.d/nfsconf
	stamp $@

init_nfsconf:
	echo "NFS_CLIENT=1" > /etc/rc.config.d/nfsconf
	echo "NFS_SERVER=0" >> /etc/rc.config.d/nfsconf
	echo "AUTOMOUNT=0" >> /etc/rc.config.d/nfsconf
	echo "NUM_NFSIOD=0" >> /etc/rc.config.d/nfsconf
	trigger /etc/rc.config.d/nfsconf
	stamp $@

hp-enable-automount:
	echo "AUTOMOUNT=1" >> /etc/rc.config.d/nfsconf
	trigger /etc/rc.config.d/nfsconf
	stamp $@

ignitenfsexports:
	echo /var/opt/ignite/clients -anon=2 >> /etc/exports
	echo /var/opt/ignite/archives -anon=2,ro >> /etc/exports
	stamp $@

depotexports:
	echo /isconf/filesets/depot -anon=2,ro >> /etc/exports
	stamp $@

fix-install-perms:
	$(IS_ROOTDIR)/lib/targets/hp-ux/fix-install-perms
	stamp $@

enable-trusted-system:
	/usr/lbin/tsconvert
	/usr/lbin/modprpw -V
	stamp $@

dmesg-cron:
	cronedit -user root -add '0,5,10,15,20,25,30,35,40,45,50,55 * * * * /usr/sbin/dmesg - >> /var/adm/messages'
	stamp $@

# fs and lvm patches

fs_patches:
	pkginstall --reboot --pkg FC-AL_Patches-200208 --release `uname -r` --vendor HP
	stamp $@


# interface manipulation targets

netbackup-gige:
	$(IS_ROOTDIR)/lib/targets/hp-ux/lanconfig --enable lan5 --ip 192.168.61.15 --netmask 0xffffff00
	touch .reboot_needed
	stamp $@

netbackup-disable-100m:
	$(IS_ROOTDIR)/lib/targets/hp-ux/lanconfig --disable lan0
	touch .reboot_needed
	stamp $@

# infolease stanzas

# this is a really nasty one-off
# it should really, really be done differently
oracle-kernel-params_1.0:
	cp /stand/system /stand/system.dist
	echo "dnlc_hash_locks 512" >> /stand/system
	echo "maxdsiz         1073741824" >> /stand/system
	echo "maxdsiz_64bit   0X40000000" >> /stand/system
	echo "maxssiz         134217728" >> /stand/system
	echo "maxssiz_64bit   1073741824" >> /stand/system
	echo "maxtsiz         0X4000000" >> /stand/system
	echo "maxtsiz_64bit   0X40000000" >> /stand/system
	echo "maxuprc         2048" >> /stand/system
	echo "msgmni          4096" >> /stand/system
	echo "msgseg          16384" >> /stand/system
	echo "msgtql          4096" >> /stand/system
	echo "ncsize          35840" >> /stand/system
	echo "nfile           63488" >> /stand/system
	echo "nflocks         4096" >> /stand/system
	echo "ninode          34816" >> /stand/system
	echo "nproc           4096" >> /stand/system
	echo "semmni          8192" >> /stand/system
	echo "semmns          16384" >> /stand/system
	echo "semmnu          4092" >> /stand/system
	echo "shmmax          1073741824" >> /stand/system
	echo "shmmni          512" >> /stand/system
	echo "shmseg          32" >> /stand/system
	echo "vps_ceiling     64" >> /stand/system
	mk_kernel -o /stand/vmunix
	stamp $@
	#${MAKE} -f ${IS_MAINMAKE} reboot

#------------------------------------------------------------------------#
# DO NOT COPY THESE STANZAS
# these are the original install stanzas, and should not be emulated
# instead add your package to the above macro definitions (e.g., the
# PKGS macro)
cvs1.11.1.p1: 
	pkginstall --pkg CVS --release 1.11.1.p1 --vendor CFSC
	stamp $@

bash2.05: 
	pkginstall --pkg bash --release 2.05 --vendor CFSC
	cp /usr/local/bin/bash /usr/bin
	stamp $@

perl5.6.1:
	pkginstall --pkg perl --release 5.6.1 --vendor CFSC
	stamp $@

rsync2.4.6:
	pkginstall --pkg rsync --release 2.4.6 --vendor CFSC
	stamp $@

less358:
	pkginstall --pkg less --release 358 --vendor CFSC
	stamp $@

openssh2.9p2:
	pkginstall --pkg openssh --release 2.9p2 --vendor CFSC
	stamp $@

gzip1.2.4a:
	pkginstall --pkg gzip --release 1.2.4a --vendor CFSC
	stamp $@

sudo1.6.3b7:
	pkginstall --pkg sudo --release 1.6.3b7 --vendor CFSC
	stamp $@

# DO NOT COPY THESE STANZAS
#------------------------------------------------------------------------#


#------------------------------------------------------------------------#
# rsync-related stanzas
#----------
# this is a repeating stanza, and it gets run if either of the listed
# files is newer than /etc/rsyncd.conf
/etc/rsyncd.conf: mk_rsynconfigdir /var/isconf/etc/rsynclist
	rsynconfig --build
	trigger $@

# this is where we create each of the files
# this MUST be run before we add the config to rsync
# i badly named this initially...
rsync/mkconfig__% rsync/rmconfig__%: mk_rsynconfigdir
	mkdir -p rsync
	rsyncmods --isconf $@
	stamp $@

# generic stanza to add or delete an rsync module
rsync/add__% rsync/rm__%: mk_rsynconfigdir
	mkdir -p rsync
	set -- `echo $@ | sed -e 's/rsync\///' -e 's/__/ /g'`; \
	CMD=$$1 MODULE=$$2; \
	rsynconfig --$$CMD $$MODULE
	stamp $@

/sbin/init.d/rsyncd:
	rsyncstartup

/etc/rc.config.d/rsyncd:
	echo RSYNCD=1 > /etc/rc.config.d/rsyncd

# make the config dir
mk_rsynconfigdir: /sbin/init.d/rsyncd ln/sbin--init.d--rsyncd__sbin--rc2.d--S500rsyncd \
/etc/rc.config.d/rsyncd
	mkdir -p $(IS_RSYNCFGDIR)
	stamp $@
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# inetd.conf services 

#-------------------------------------------
# The following stanza will copy service and inetd configs over to the local host
# and enable them on the host
# it calls a few sub-stanzas
inetd/install__%:
	mkdir -p inetd
	set -- `echo $@ | sed -e 's/inetd\/install__//'`; \
	SERVICE=$$1; \
	$(MAKE) -f $(IS_MAINMAKE) service/copy__$$SERVICE inetd/copy__$$SERVICE \
	inetd/add__$$SERVICE
	stamp $@

service/copy__%:
	mkdir -p service
	set -- `echo $@ | sed -e 's/service\/copy__//'`; \
	SERVICE=$$1; \
	cp /var/isconf/lib/services/$(IS_OS)/$$SERVICE /var/isconf/etc/inetdconfig/service.$$SERVICE
	stamp $@

inetd/copy__%:
	mkdir -p inetd
	set -- `echo $@ | sed -e 's/inetd\/copy__//'`; \
	SERVICE=$$1; \
	cp /var/isconf/lib/inetd/$(IS_OS)/$$SERVICE /var/isconf/etc/inetdconfig/inetd.$$SERVICE
	stamp $@

inetd/del__%:
	mkdir -p inetd
	set -- `echo $@ | sed -e 's/inetd\/del__//'`; \
	SERVICE=$$1; \
	inetd-config --del $$SERVICE
	stamp $@
	inetd-build

inetd/add__%:
	mkdir -p inetd
	set -- `echo $@ | sed -e 's/inetd\/add__//'`; \
	SERVICE=$$1; \
	inetd-config --add $$SERVICE
	stamp $@
	inetd-build
# end of generic inetd stanzas
#-------------------------------------------

addrsa_services:
	echo 'securidprop          5505/tcp        # Aceserver' \
	>  /var/isconf/etc/inetdconfig/service.ace
	echo 'securid              5500/udp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_00       5505/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_01       5506/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_02       5507/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_03       5508/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_04       5509/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_05       5510/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_06       5511/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_07       5512/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_08       5513/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_09       5514/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'securidprop_10       5515/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdlog                5520/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdserv               5530/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdadmind             5550/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdreport             5540/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdlockmgr            5560/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'sdcommd              5570/tcp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'tacacs               49/tcp          # TACACS+ Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'radius               1645/udp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	echo 'radacct              1646/udp        # Aceserver' \
	>> /var/isconf/etc/inetdconfig/service.ace
	touch /var/isconf/etc/inetdconfig/inetd.ace
	inetd-config --add ace
	stamp $@
	inetd-build

fixrsa_services1:
	cp /var/isconf/etc/inetdconfig/service.ace /var/isconf/etc/inetdconfig/service.ace.bak
	sed 's/securidprop_05/securidprop/' /var/isconf/etc/inetdconfig/service.ace.bak > /var/isconf/etc/inetdconfig/service.ace
	stamp $@
	inetd-build

fixrsa_services2:
	cp /var/isconf/etc/inetdconfig/service.ace /var/isconf/etc/inetdconfig/service.ace.bak
	sed 's/^sdreport/sdxauthd/' /var/isconf/etc/inetdconfig/service.ace.bak > /var/isconf/etc/inetdconfig/service.ace
	stamp $@
	inetd-build

statd_service: inetd_configdir
	echo "rpc dgram udp wait root /usr/lib/netsvc/rstat/rpc.rstatd 100001 2-4 rpc.rstatd" \
	> /var/isconf/etc/inetdconfig/inetd.statd
	inetd-config --add statd
	stamp $@
	inetd-build
	trigger /etc/inetd.conf

netbackup_service: inetd_configdir
	echo "bprd 13720/tcp bprd # Netbackup" \
	> /var/isconf/etc/inetdconfig/service.netbackup
	echo "bpcd 13782/tcp bpcd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "vopied 13783/tcp vopied # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "bpjava-msvc 13722/tcp bpjava-msvc # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "vnetd   13724/tcp       vnetd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "bpjobd  13723/tcp       bpjobd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "nbdbd   13784/tcp       nbdbd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "visd    9284/tcp        visd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup
	echo "bpcd stream tcp nowait root /usr/openv/netbackup/bin/bpcd bpcd" \
	> /var/isconf/etc/inetdconfig/inetd.netbackup
	echo "vopied stream tcp	nowait root /usr/openv/bin/vopied vopied"     \
	>> /var/isconf/etc/inetdconfig/inetd.netbackup
	echo "bpjava-msvc stream tcp nowait root /usr/openv/netbackup/bin/bpjava-msvc bpjava-msvc -transient" \
	>> /var/isconf/etc/inetdconfig/inetd.netbackup
	echo "vnetd   stream  tcp     nowait  root    /usr/openv/bin/vnetd vnetd" \
	>> /var/isconf/etc/inetdconfig/inetd.netbackup
	inetd-config --add netbackup
	stamp $@
	inetd-build
	trigger /etc/inetd.conf

standard_service:
	$(IS_ROOTDIR)/lib/targets/hp-ux/serviceinit
	inetd-config --add standard
	inetd-build
	stamp $@

netbackup_server_service: inetd_configdir
	echo "bpdbm   13721/tcp       bpdbm # Netbackup" \
	> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "vmd     13701/tcp       vmd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "acsd    13702/tcp       acsd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tl8cd   13705/tcp       tl8cd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "odld    13706/tcp       odld # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "vtlcd   13708/tcp       vtlcd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "ts8d    13709/tcp       ts8d # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tldcd   13711/tcp       tldcd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tl4d    13713/tcp       tl4d # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tsdd    13714/tcp       tsdd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tshd    13715/tcp       tshd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tlmd    13716/tcp       tlmd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "tlhcd   13717/tcp       tlhcd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "lmfcd   13718/tcp       lmfcd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	echo "rsmd    13719/tcp       rsmd # Netbackup" \
	>> /var/isconf/etc/inetdconfig/service.netbackup_server
	inetd-config --add netbackup_server
	stamp $@
	inetd-build
	trigger /etc/inetd.conf

telnet_service: inetd_configdir
	echo "telnet 23/tcp # Virtual Terminal Protocol" \
	> /var/isconf/etc/inetdconfig/service.telnet
	echo "telnet stream tcp nowait root /usr/lbin/telnetd telnetd -b /etc/issue" \
	> /var/isconf/etc/inetdconfig/inetd.telnet
	inetd-config --add telnet
	stamp $@
	inetd-build

ftp_service: inetd_configdir
	echo "ftp-data 20/tcp # File Transfer Protocol (Data)" \
	> /var/isconf/etc/inetdconfig/service.ftp
	echo "ftp 21/tcp # File Transfer Protocol (Control)" \
	>> /var/isconf/etc/inetdconfig/service.ftp

	echo "ftp stream tcp nowait root /usr/lbin/ftpd ftpd -l" \
	> /var/isconf/etc/inetdconfig/inetd.ftp
	inetd-config --add ftp
	inetd-build
	stamp $@

instl_bootd_service: inetd_configdir
	echo 'instl_boots 1067/udp # installation bootstrap protocol server' \
	> /var/isconf/etc/inetdconfig/service.instl_bootd
	echo 'instl_bootc 1068/udp # installation bootstrap protocol client' \
	>> /var/isconf/etc/inetdconfig/service.instl_bootd
	echo 'instl_boots dgram udp wait root /opt/ignite/lbin/instl_bootd instl_bootd' \
	> /var/isconf/etc/inetdconfig/inetd.instl_bootd
	stamp $@

ignite_tftp_service: inetd_configdir
	echo 'tftp 69/udp # Trivial File Transfer Protocol' \
	> /var/isconf/etc/inetdconfig/service.tftp
	echo 'tftp dgram udp wait root /usr/lbin/tftpd tftpd /opt/ignite /var/opt/ignite' \
	> /var/isconf/etc/inetdconfig/inetd.tftp
	inetd-build
	stamp $@

tftp_service: inetd_configdir
	echo "tftp 69/udp # Trivial File Transfer Protocol" \
	> /var/isconf/etc/inetdconfig/service.tftp
	echo "tftp dgram udp wait root /usr/lbin/tftpd tftpd" \
	> /var/isconf/etc/inetdconfig/inetd.tftp
	inetd-config --add tftp
	inetd-build
	stamp $@

rlogin_service: inetd_configdir
	echo "login 543/tcp eklogin rlogin # Remote login" \
	> /var/isconf/etc/inetdconfig/service.rlogin
	echo "login stream tcp nowait root /usr/lbin/rlogind rlogind" \
	> /var/isconf/etc/inetdconfig/inetd.rlogin
	inetd-config --add rlogin
	stamp $@
	inetd-build

/etc/inetd.conf: /var/isconf/etc/inetdconfig /var/isconf/etc/inetdtab
	echo "Creating inetd.conf..."
	inetd-build

#------------------------------------------------------------------------#
# stanzas to create filesystem stuff

#-------------
# the old stanzas are below, and are being replaced with these ones:

# this is useless unless we have a make that supports %
# filesystems/new__<vg>__<volume name>__<size>__<path--to--mount--on>
filesystems/new__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/new__//' -e 's/__/ /g'`; \
	VG=$$1; LV=$$2; SIZE=$$3; VGPATH=$$4; \
	$(MAKE) -f $(IS_MAINMAKE) filesystems/newlv__$${VG}__$${LV}__$${SIZE} \
	filesystems/newfs__$${VG}__$${LV} \
	filesystems/addmount__$${VG}__$${LV}__$${VGPATH} \
	filesystems/mount__$${VGPATH}
	stamp $@

# filesystems/newlv__<vg>__<lv>__<size in mb>
filesystems/newlv__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/newlv__//' -e 's/__/ /g'`; \
	VG=$$1; LV=$$2; SIZE=$$3; \
	lvcreate -m 1 -L $$SIZE -n $$LV $$VG
	stamp $@

# filesystems/newfs__<vg>__<lv>
filesystems/newfs__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/newfs__//' -e 's/__/ /g'`; \
	VG=$$1; LV=$$2; \
	newfs /dev/$$VG/r$$LV
	stamp $@

# filesystems/addmount__<vg>__<lv>__<path--to--dir>
filesystems/addmount__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/addmount__//' -e 's/__/ /g'`; \
	VG=$$1; LV=$$2; VGPATH=`echo $$3 | sed -e 's/--/\//g' -e 's/^/\//'`; \
	echo "/dev/$$VG/$$LV $$VGPATH vxfs delaylog 0 2" >> /etc/fstab
	stamp $@

# filesystems/mount__<path--to--dir>
filesystems/mount__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/mount__//' -e 's/__/ /g'`; \
	VGPATH=`echo $$1 | sed -e 's/--/\//g' -e 's/^/\//'`; \
	mkdir -p $$VGPATH; \
	mount $$VGPATH
	stamp $@

# filesystems/importvg__<vg>__<minor>
filesystems/importvg__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/importvg__//' -e 's/__/ /g'`; \
	VG=$$1; MINOR=$$2; \
	mkdir -p /dev/$$VG; \
	mknod /dev/$$VG/group c 64 $$MINOR; \
	vgimport -m $$IS_CONFDIR/vgs/$$IS_HOSTNAME/$$VG.map -f $$IS_CONFDIR/vgs/$$IS_HOSTNAME/$$VG.dsk $$VG
	vgchange -a y $$VG
	stamp $@

# filesystems/importfs__<vg>__<lv>__<path--to--mount--on>
filesystems/importfs__%:
	mkdir -p filesystems
	set -- `echo $@ | sed -e 's/filesystems\/importfs__//' -e 's/__/ /g'`; \
	VG=$$1; LV=$$2; VGPATH=$$3; \
	filesystems/addmount__$${VG}__$${LV}__$${VGPATH} \
	filesystems/mount__$${VGPATH}
	stamp $@

#----------------
# DON'T USE THESE ANYMORE
# DON'T USE THESE ANYMORE
# use the above stanzas instead
mkfs_600-ud40-boot mkfs_2048-rsa-boot newlv_13890-netbackup-vgveritas:
	SIZE=`echo $@ | sed "s/^..*_//" | sed "s/-..*$$//"`; \
	LV=`echo $@ | sed "s/[^-][^-]*-//" | sed "s/-[^-][^-]*$$//"`; \
	VG=`echo $@ | sed "s/^..*-//"`; \
	lvcreate -m 1 -L $$SIZE -n $$LV $$VG
	stamp $@

newfs_ud40-boot newfs_rsa-boot newfs_13890-netbackup-vgveritas:
	LV=`echo $@ | sed "s/^..*_//" | sed "s/-[^-][^-]*$$//"`; \
	VG=`echo $@ | sed "s/^..*-//"`; \
	newfs /dev/$$VG/r$$LV
	stamp $@

mountfs_ud40-boot-opt_ud40 mountfs_rsa-boot-rsa \
mountfs_netbackup-vgveritas-opt_openv:
	cp /etc/fstab /etc/fstab.`date +%Y%m%d%H%m%S`
	set -- `echo $@ | sed -e 's/mountfs_//' -e 's/-/ /g'`; \
	LV=$$1; VG=$$2; MNT=`echo $$3 | sed -e 's/_/\//g' -e 's/^/\//'`; \
	echo "/dev/$$VG/$$LV $$MNT vxfs delaylog 0 2" >> /etc/fstab; \
	mkdir -p $$MNT; \
	mount $$MNT
	stamp $@
# DON'T USE THESE ANYMORE
# DON'T USE THESE ANYMORE
#----------------

#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# these stanzas are used to install packages
# they just call the pkginstall script with the --isconf option, leaving
# it up to the script to parse out the correct arguments
# make _MUST_ be a literal macro
pkg/make--3.79.1--CFSC pkg/%:
	mkdir -p pkg
	pkginstall --isconf $@
	stamp $@

# this is for packages which require a reboot
#$(REBOOTPKGS):
#	mkdir -p pkg
#	pkginstall --reboot --isconf $@
#	stamp $@
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
# more generic stanzas

# allowing a user to use cron
cron/allow__%:
	mkdir -p cron
	set -- `echo $@ | sed 's/cron\/allow__//'`; USER=$$1; \
	if [ -z "`grep $$USER /var/adm/cron/cron.allow`" ]; then \
		echo $$USER >> /var/adm/cron/cron.allow; \
	fi
	stamp $@

# enable or disable a lan port
# lanconfig/<enable|disable>--<interface>--<ip address>--<netmask>
lanconfig/%:
	mkdir -p lanconfig
	set -- `echo $@ | sed -e 's/lanconfig\///' -e 's/--/ /g'`; \
	CMD=$$1; IF=$$2; IP=$$3; NETMASK=$$4; \
	$(IS_ROOTDIR)/lib/targets/hp-ux/lanconfig --$$CMD $$IF --ip $$IP --netmask $$NETMASK
	stamp $@

# clustering stanzas
# these configure the VCS cluster
vcs/configure: vcs/license vcs/llthosts vcs/llttab vcs/gabtab

vcs/license:
	mkdir -p vcs
	LICENSE=`islicense VRTSvcs`; export LICENSE; \
	cd /opt/VRTSvcs/install; \
	perl -e "print qq($$IS_HOSTNAME\n$$LICENSE\n)" | /opt/VRTSvcs/install/licensevcs
	stamp $@

vcs/llthosts:
	mkdir -p vcs
	echo $$CLUSTER_MEMBERS
	count=1; export count; \
	for host in $$CLUSTER_MEMBERS; do \
		echo $$count $$host >> /etc/llthosts; \
		count=`perl -e "print $$count + 1, qq(\n)";`; \
	done
	stamp $@

vcs/llttab: vcs/llthosts
	mkdir -p vcs
	count=1; export count; \
	for host in $$CLUSTER_MEMBERS; do \
		if [ "$$host" = "$$IS_HOSTNAME" ]; then \
			node=$$count; export node; fi; \
		count=`perl -e "print $$count + 1, qq(\n)";`; \
	done; \
	echo set-node $$node > /etc/llttab
	echo set-cluster $(CLUSTERID) >> /etc/llttab
	echo set-verbose 1 >> /etc/llttab
	echo set-nofastpath 1 >> /etc/llttab
	echo link lan1 /dev/lan:1 - ether - - >> /etc/llttab
	echo link-lowpri lan0 /dev/lan:0 - ether - - >> /etc/llttab
	stamp $@

vcs/gabtab:
	mkdir -p vcs
	echo gabdiskhb -a /dev/vggab/gabdisk -s 0 -p a >> /etc/gabtab
	echo gabdiskhb -a /dev/vggab/gabdisk -s 128 -p h >> /etc/gabtab
	echo gabconfig -c -n 2 >> /etc/gabtab
	stamp $@

# end of VCS stanzas
#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
# load the version-specific stanzas
include $(IS_CONFDIR)/$(IS_OS)-$(IS_OSVERSION).mk
#------------------------------------------------------------------------#
