# $Id: main.mk,v 1.1 2003/07/25 00:46:09 loosifer Exp $
# vim: syntax=make

#------------------------------------------------------------------------#
# these are catch stanzas, in case something goes wrong
all: 
	@echo usage: isconf CONTEXT
	exit 126

# just something to do; this is for the 'avialable' host type
true:
	true

# NOTE: the exclude stanza is normally never executed and is only here
# to catch errors in the 'isconf' script.  The isconf script
# itself should catch excludes
exclude:
	@echo excluding $(IS_HOSTNAME) from configuration management -- exiting
	exit 127

rebuild_inetd:
	if [ -d /var/isconf/etc/inetdconfig/ ];	then \
		/var/isconf/lib/targets/inetd-build; \
	fi
	trigger /etc/inetd.conf
#
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
#
# the first lines are the macro definitions, which will
# all be called with the same stanzas, all defined below
#
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# any filesets that need to be removed should be added to this
# list
# the format is rmfilesets-<fileset name>
#
RMFILESETS = filesets/rm__%
#
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
#
# now we define individual stanzas which can't be abstracted
#
#------------------------------------------------------------------------#
#
#
cfkeycp:
	cp /var/cfengine/ppkeys/localhost.pub /etc/cfkey.pub
	chmod 644 /etc/cfkey.pub
	stamp $@

cfinit:
	echo 'control: domain = ( ExecResult(/bin/domainname) ) actionsequence = ( copy ) copy: /var/opt/cfengine/inputs/update.conf dest=/var/cfengine/inputs/update.conf server=cfengine.fpd.cat.com trustkey=true' | /usr/local/sbin/cfagent -v -f -
	stamp $@

setdomain:
	/usr/local/scripts/setdomain
	stamp $@

cfengine_service: inetd_configdir
	echo "cfengine 5308/tcp # Cfengine" > /var/isconf/etc/inetdconfig/service.cfengine
	inetd-config --add cfengine
	inetd-build
	stamp $@

fpd_cfengine_service: inetd_configdir
	if [ ! "`grep cfengine /etc/services`" ]; then \
		echo "cfengine 5308/tcp # Cfengine" >> /etc/services; \
	fi
	stamp $@

add-logical-interface:
	for each in $$VIPS_ADD; do \
		NAME=`echo $$each|awk -F, '{print $$1}'`; \
		NUMBER=`echo $$each|awk -F, '{print $$1}'`; \
		IP=`echo $$each|awk -F, '{print $$1}'`; \
		/var/isconf/lib/targets/vipconfig -add -name $$NAME -number $$NUMBER -ip $$IP; \
	done 
	stamp $@

add-oracle-cron-minnow:
	echo oracle >> /var/adm/cron/cron.allow
	cronedit -user oracle -add '30 19 * * 0-4 ksh /u01/app/oracle/local/tools/run_730_exp.sh >/dev/null 2>&1'
	stamp $@

add-weblogic1-cron:
	echo weblogic >> /etc/cron.d/cron.allow
	cronedit -user weblogic -add '00 04 * * 6 cd /var/ebusiness/fcc/financexpress/fe-uat/run/ ;./stopAndStartFE.sh > /var/tmp/stopAndStartFE.log 2>&1'
	stamp $@

add-cricket-mkdiskcfg:
	cronedit -user adm -add '0 0 * * * /usr/local/scripts/mkdiskcfg | mailx -s "Config file for `hostname`" cricket@cricket.fpd.cat.com'
	stamp $@

add-cricket-fsinfo:
	cronedit -user adm -add '0 * * * * /usr/local/scripts/fsinfo | mailx -s "Disk data file for `hostname`" cricket@cricket.fpd.cat.com'
	stamp $@

rm-cricket-mkdiskcfg:
	- cronedit -user adm -delete "/usr/local/scripts/mkdiskcfg"
	stamp $@

rm-cricket-fsinfo:
	- cronedit -user adm -delete "/usr/local/scripts/mkdiskcfg"
	stamp $@

uselogin-sshd:
	cp /usr/local/etc/sshd_config /usr/local/etc/sshd_config.bak
	sed '/UseLogin/s/^..*/UseLogin yes/' /usr/local/etc/sshd_config.bak > /usr/local/etc/sshd_config
	stamp $@

rsync_all:
	fileset -sync-all

aliases-backup:
	cp /etc/mail/aliases /etc/mail/aliases.`date +%Y%m%d%H%m%S`
	rsync -avz rsync::filesets/common/etc/mail/aliases /etc/mail/aliases
	trigger /etc/mail/aliases
	stamp $@

failure:
	exit 1

add-cvs-user:
	useradd -c "CVS anon user" -d /opt/cvs -m -s /usr/lib/rsh -g cvs -u 15 cvs
	stamp $@

etc-hosts-cron:
	cronedit -user root -delete "52 4 * * * /usr/local/scripts/newetchosts"
	cronedit -user root -add "52 4 * * * /usr/local/scripts/newetchosts -quiet"
	stamp $@

rm-etc-hosts-cron:
	cronedit -user root -delete "52 4 * * * /usr/local/scripts/newetchosts"
	stamp $@

etc-hosts-cron2:
	cronedit -user root -add "52 4 * * * /usr/local/scripts/newetchosts -quiet"
	stamp $@

cvsdirs_cron:
	cronedit -user root -add "`randomcron -period hour` /usr/local/scripts/cvsdirs -quiet"
	stamp $@

hourly_cron:
	cronedit -user root -add "`randomcron -period hour` /var/isconf/bin/cronwrap -context HOURLY"
	stamp $@

daily_cron:
	cronedit -user root -add "`randomcron -period day` /var/isconf/bin/cronwrap -context DAILY"
	stamp $@

known_hosts_cron:
	cronedit -user root -add "`randomcron -period day` /usr/local/scripts/newknownhosts -dir /isconf/filesets/applications/known_hosts/ -quiet"
	stamp $@

rmknown_hosts_cron:
	cronedit -user root -delete "/usr/local/scripts/newknownhosts -dir /isconf/filesets/applications/known_hosts"
	stamp $@

rm_cvsdirs_cron:
	cronedit -user root -delete "/usr/local/scripts/cvsdirs -quiet"
	cronedit -user root -delete "/usr/local/scripts/newknownhosts -quiet"
	stamp $@

change-root-home:
	$(IS_ROOTDIR)/lib/targets/change-root-home
	stamp $@

set-root-GCOS:
	$(IS_ROOTDIR)/lib/targets/set-root-GCOS
	stamp $@

setup-anon-cvs:
	$(IS_ROOTDIR)/bin/setupcvs
	stamp $@

#------------------------------------------------------------------------#
#------------------------------------------------------------------------#
# below this point is where all of the generic macros are defined
# this will probably be pulled into a separate library at some point
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# copying from filesets/install
# installcopy/copy--cfengine--2.0.4
installcopy/copy--%:
	mkdir -p installcopy
	mkdir -p /usr/local/install
	set -- `echo $@ | sed -e 's/installcopy\/copy--//;s/--/\//g'`; \
	PACKAGE=$$1; VERSION=$$2; \
	mkdir -p /usr/local/install/$$PACKAGE/; \
	/usr/local/bin/rsync -avz $$pkgname.fpd.cat.com::filesets/install/${IS_OS}/${IS_OSVERSION}/$$PACKAGE/$$VERSION/. /usr/local/install/$$PACKAGE/$$VERSION/
	stamp $@

# installcopy/cfenginelinks
installcopy/cfenginelinks:
	mkdir -p installcopy
	- for file in /usr/local/install/cfengine/2.0.4/sbin/*; do \
		ln -s $$file /usr/local/sbin; \
	done
	- for file in /usr/local/install/openssl/0.9.6g/lib/*; do \
		ln -s $$file /usr/local/lib; \
	done
	- for file in /usr/local/install/db/3.3.11/lib/*; do \
		ln -s $$file /usr/local/lib; \
	done
	- ln -s /usr/local/lib/libdb-3.3.${libext} /usr/local/lib/libdb.${libext}
	stamp $@

installcopy/cfengine-init:
	mkdir -p installcopy
	/usr/local/sbin/cfkey
	mkdir -p /var/cfengine/inputs
	mkdir -p /var/cfengine/outputs
	stamp $@

#------------------------------------------------------------------------#
# installing filesets
filesets/add__%:
	mkdir -p filesets
	fileset --add `echo $@ | sed 's/filesets\/add__//'`
	- fileset --rsync `echo $@ | sed 's/filesets\/add__//'`
	- modechk
	- trigger
	stamp $@

filesets-%:
	SET=`echo $@ | sed 's/^[^-][^-]*-//'`; fileset -add $$SET
	- SET=`echo $@ | sed 's/^[^-][^-]*-//'`; fileset -rsync $$SET
	- modechk
	- trigger
	stamp $@

# removing filesets
filesets/rm_%:
	mkdir -p filesets
	set -- `echo $@ | sed 's/filesets\/rm__//'`; \
	SET=$$1; \
	fileset --rm $$SET
	stamp $@

# making directories
mkdir%:
	mkdir -p mkdir
	DIR=`echo $@ | sed -e 's/^mkdir//' -e 's/--/\//g'`; mkdir -p $$DIR
	stamp $@

# add groups
groupadd/%:
	mkdir -p groupadd
	GROUP=`echo $@ | sed -e 's/^groupadd\///' -e 's/__..*$$//'`; \
	GID=`echo $@ | sed -e 's/^..*__//'`; \
	groupadd -g $$GID $$GROUP
	stamp $@

# chowning directories
# THIS IS ALWAYS RECURSIVE
chown/%:
	mkdir -p chown
	DIR=`echo $@ | sed -e 's/^chown\///' -e 's/__..*$$//g' -e 's/--/\//g' -e 's/^/\//'`; \
	USER=`echo $@ | sed -e 's/[^_][^_]*__//' -e 's/__..*$$//g'`; \
	GROUP=`echo $@ | sed -e 's/..*__//'`; \
	chown -R $$USER:$$GROUP $$DIR
	stamp $@

# chmoding files


#------------------------------------------------------------------------#
# untarring files
tar/%:
	mkdir -p tar
	TAR=`echo $@ | sed -e 's/[^/][^/]*\///' -e 's/-[^-][^-]*$$//'`; \
	DIR=`echo $@ | sed -e 's/[^-][^-]*-//' -e 's/_/\//g' -e 's/^/\//'`; \
	$(IS_ROOTDIR)/bin/gettar -tar $$TAR -dir $$DIR
	stamp $@
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# performing soft links
ln/%:
	mkdir -p ln
	FROM=`echo $@ | sed -e 's/[^/][^/]*\///' -e 's/__[^_][^_]*//' \
	-e 's/--/\//g' -e 's/^/\//'`; \
	TO=`echo $@ | sed -e 's/..*__//' -e 's/--/\//g' -e 's/^/\//'`; \
	/usr/bin/ln -s $$FROM $$TO
	stamp $@
#------------------------------------------------------------------------#

#------------------------------------------------------------------------#
# removing stuff
rm/norecurse--%:
	mkdir -p rm
	set -- `echo $@ | sed -e 's/rm\/norecurse--//;s/__/\//g;s/^/\//'`; \
	FILE=$$1; \
	rm $$FILE
	stamp $@

rmdir/%:
	mkdir -p rmdir
	DIR=`echo $@ | sed -e 's/rmdir\///' -e 's/--/\//' -e 's/^/\//'`; \
	rmdir $$DIR
	stamp $@
#------------------------------------------------------------------------#
# removing stuff

# opc just randomly chooses its account stuff, and i want it to be consistent
fix-opc-group:
	groupmod -o -g 16 opcgrp
	stamp $@

#------------------------------------------------------------------------#
# OS-independent inetd.conf configuration commands

inetd_configdir:
	if [ ! -d "/var/isconf/etc/inetdconfig" ]; then   \
		mkdir /var/isconf/etc/inetdconfig;        \
	fi
	stamp $@

/var/isconf/etc/inetdconfig:
	mkdir /var/isconf/etc/inetdconfig

/var/isconf/etc/inetdtab:
	touch /var/isconf/etc/inetdtab

#------------------------------------------------------------------------#
# OS-independent buildhost commands

buildhost-links:
	if [ ! -h "/usr/local/src" ]; then		\
		ln -s /net/src /usr/local/src;		\
	fi
	if [ ! -h "/usr/local/build" ]; then		\
		ln -s /net/build /usr/local/build;	\
	fi
	stamp $@

#------------------------------------------------------------------------#
# pull in the external make files
include $(IS_CONFDIR)/$(IS_OS).mk
#------------------------------------------------------------------------#
