package Isconf;
####################################################################################
####################################################################################
# Isconf
####################################################################################
####################################################################################

use Exporter;
use vars qw(@ISA @EXPORT $VERSION);

@ISA = qw(Exporter);
@EXPORT = qw(
	assert
	configchk
	config
	debug
	error
	sum_chk
	sum_set
);

# this lets cvs manage our version number
$VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);

####################################################################################
# Isconf::File::Target::assert
sub assert {
	my (@cmd) = @_;
	if ($::DEBUG) {
		unshift @cmd, 'set -x;';
	}
	if ($::NOOP) {
		print "NOOP: ", join(" ",@cmd), "\n";
		return;
	} else {
		system(join(" ",@cmd));
	}
	my $exit = $? >> 8;

	if ($exit) {
		warn "Command [@_] failed\n";
	}
	return $exit;
}
# Isconf::File::Target::assert
####################################################################################

####################################################################################
# Isconf::config
# imports the init.conf file and sets up the %ENV hash

sub config {
	my ($env,$var,$value,$dir);

	if ($::CONTEXT) {
	    $ENV{'CONTEXT'} = $::CONTEXT;
	} elsif (exists $ENV{'CONTEXT'}) {
	    $::CONTEXT = $ENV{'CONTEXT'};
	} else {
	    print "Setting context to 'NULL'\n";
	    $ENV{'CONTEXT'} = $::CONTEXT = 'NULL';
	}

	$ENV{'IS_ROOTDIR'} ||= "/var/isconf";
	$ENV{'IS_INITFILE'} ||= "$ENV{'IS_ROOTDIR'}/conf/init.conf";
	
	$env = qx(. $ENV{'IS_INITFILE'}; set) or die error("Could not source init.conf\n");
	
	foreach (split /\n/, $env) {
		/^IFS=/ and next; # we know we don't need to import IFS, and it's got a carriage return
		/^SHELLOPTS=/ and next; # bash hates this
		($var,$value) = split /=/ or next;
		unless ($value) { next; }
		$value =~ /.\(\)/ and last; # we don't want function definitions
		$value =~ s/^['"]//;
		$value =~ s/['"]$//;
		debug("$var is [$value]");
		$ENV{$var} = $value;
	}
	
		foreach $dir ($ENV{'IS_STAMPDIR'}, "$ENV{'IS_ROOTDIR'}/etc",
						"$ENV{'IS_ROOTDIR'}/logs", "$ENV{'IS_ROOTDIR'}/tmp") {
			if (! -d $dir) {
				mkdir $dir;
			}
		}
	
	$ENV{'IS_LOGFILE'} =~ s/isconf\.[^\/]+\.log/isconf.$::CONTEXT.log/;
	
	unless ($ENV{'IS_PLATFORM'}) {
		die error("IS_PLATFORM is unset -- check init.conf\n");
	}
}

# Isconf::File::Target::config
####################################################################################

####################################################################################
# Isconf::configchk
sub configchk {
	unless (exists $ENV{'IS_ROOTDIR'}) {
		die "IS_ROOTDIR is not set\n";
	}

	my ($var,%args);
	%args = @_;

	unless (exists $args{'vars'} and ref $args{'vars'}) {
		return;
	}

	foreach $var (@{ $args{'vars'} }) {
		unless (exists $ENV{$var}) {
			error("Variable $var is not set.");
			return 0;
		}
	}
	return 1;
}
# Isconf::configchk
####################################################################################

####################################################################################
# Isconf::debug
sub debug {
	unless ($::DEBUG) { return; }
	if (ref $_[0]) {
		my $obj = shift or return;
		my $level = shift or return;

		my $name = $obj->{'name'} || '';
		if ($::DEBUG >= $level)
		{
			warn ref $obj, "($name): @_\n";
		}
	} else {
		warn "$0: @_\n";
	}
	return 1;
}
# Isconf::debug
####################################################################################

####################################################################################
# Isconf::error
sub error {
	if (@_) {
		$Isconf::ERROR = shift(@_) . "\n";
	}

	if ($Isconf::ERROR) {
		return $Isconf::ERROR;
	}
}
# Isconf::error
####################################################################################

####################################################################################
# Isconf::lists
sub lists {
	my $obj = shift;
	my $list = shift;
	$obj->debug(10,"lists");
	$obj->debug(6,"$list");

	my $target;

	unless (exists $obj->{$list}) { return; }

	if ($var = shift) {
		if (exists $obj->{$list}->{'hash'}->{$var}) {
			$obj->debug(6,"$list: returning", $obj->{$list}->{'hash'}->{$var});
			return $obj->{$list}->{'hash'}->{$var};
		} else {
			$obj->debug(6,"$list: item doesn't exist; returning nothing");
			return;
		}
	} else {
		$obj->debug(6,"$list: returning all $list");
		#return keys %{ $obj->{$list} };
		if (exists $obj->{$list}->{'ary'}) {
			my @return;
			#foreach (values %{ $obj->{$list}->{'hash'} } ) {
			#	push @return, $_->name();
			#}
			foreach (@{ $obj->{$list}->{'ary'} }) {
				push @return, $_->name();
			}
			return @return;
		} else {
			return keys %{ $obj->{$list}->{'hash'} };
		}
	}
}
# Isconf::File::Target::lists
####################################################################################

####################################################################################
# Isconf::have_md5
sub sum_enabled {
	if (exists $ENV{'IS_USESUMS'} and ! $ENV{'IS_USESUMS'}) {
		debug("Sums are disabled");
		return;
	}
	# XXX this is currently not portable for machines whose file separator is
	# not /
	if (exists $INC{'Digest/MD5.pm'}) {
		return 1;
	}
	eval {
		require Digest::MD5;
		import Digest::MD5 qw(md5_hex);
	};

	if ($@) {
		debug("Could not load Digest::MD5: $@");
		warn "Please install Digest::MD5; sum-checking is unsupported without it\n";
		delete $INC{'Digest/MD5.pm'};
		return;
	} else {
		return 1;
	}
}
# Isconf::have_md5
####################################################################################

####################################################################################
# Isconf::File::Target::sum_chk
sub sum_chk {
	my $file = shift or
		error("sum_chk: filename must be passed as argument"), return;
	my (@lines,@sumlines,$osum,$nsum);

	unless (sum_enabled()) {
		return 1;
	}

	open FILE, $file or
		error("Could not open file '$file'"), return;
	@lines = <FILE>;
	close FILE;

	if (@sumlines = grep /^# Sum: /, @lines) {
		foreach (@sumlines) {
			/Sum: (.+)$/ and $osum = $1;
		}
	} else {
		error("File $file does not have a sum set."), return;
	}

	@lines = grep !/^# Sum:/, @lines;

	# make linux use system V sum
	#my $sysv_flag = "";
	#if (defined $ENV{'IS_OS'} && $ENV{'IS_OS'} eq 'linux') {
	#	$sysv_flag = " -s ";
	#}

	#$nsum = qx(cat $file | grep -v '^#' | sum $sysv_flag | awk '{print \$1'});
	$nsum = md5_hex(@lines);

	chomp $nsum;
	unless ($nsum) {
		error("Could not compute sum of file on $file."), return;
	}

	unless ($osum and $nsum) {
		error("Incomplete hashes on $file.");
		return;
	}
	unless ($osum eq $nsum) {
		error("Hashes do not match on $file.");
		debug("osum [$osum] nsum [$nsum]");
		return;
	}
	# if we've gotten this far, the hashes match, so we should return true.
	return $osum;
}
# Isconf::File::Target::sum_chk
####################################################################################

####################################################################################
# Isconf::File::Target::sum_set
sub sum_set {
	my $file = shift or
		error("sum_set: filename must be passed as argument."), return;

	# always return true if we aren't supporting sums
	unless (sum_enabled()) {
		return 1;
	}

	my (@lines,$sum);

	open FILE, $file or error("Could not open $file for reading."), return;
	@lines = grep !/^#/, <FILE>;
	close FILE;

	# make linux use system V sum
	#my $sysv_flag = "";
	#if (defined $ENV{'IS_OS'} && $ENV{'IS_OS'} eq 'linux') {
	#	$sysv_flag = " -s ";
	#}

	#$sum = qx(cat $file | grep -v '^#' | sum $sysv_flag | awk '{print \$1'});
	#chomp $sum;
	$sum = md5_hex(@lines);

	open FILE, ">$file" or error("Could not open $file for writing.");
	print FILE @lines, "# Sum: $sum\n";
	close FILE;
	return $sum;
}
# Isconf::File::Target::sum_set
####################################################################################

=head1 NAME

   Isconf - Head module for Isconf 3l

=head1 SYNOPSIS

   Isconf 

=head1 DESCRIPTION

B<Isconf>

=head1 OPTIONS

=over 4


=item dummy

	E

=back

=head1 SEE ALSO

L<Cat>

=head1 AUTHOR

Luke A. Kanies, luke.kanies@cat.com

=for html <hr>

I<$Id: Isconf.pm,v 1.9 2003/11/04 06:04:15 loosifer Exp $>

=cut
1;
