package Isconf::File::Item;
####################################################################################
####################################################################################
# Isconf::File::Item
####################################################################################
####################################################################################

use Isconf;
use Isconf::File;
use Exporter;

use vars qw(@ISA $VERSION);

@ISA = qw(Isconf Isconf::File);

####################################################################################
# Isconf::File::Item::new
sub new
{
	my ($class,%args,$obj,$var,$name,$targs,$test);
	($class,%args) = @_;
	$obj = bless {}, $class;

	$name = $args{'name'};
	$obj->name($name);

	if ($name =~ s/\((.+)\)//)
	{
		$obj->{'args'} = $1;
	}

	$obj->{'item'} = $name;
	$obj->debug(10,"new: name is $name");
	foreach $var (@{ $args{'vars'} })
	{
		$obj->debug(8,"new: var is ", $var->name);
		$obj->newvar($var->name() => $var->value());
	}

	if (exists $args{'comment'} and $args{'comment'})
	{
		$obj->debug(8,"new: item $obj->{'name'} has a comment");
		$obj->{'comment'} = $args{'comment'};
	}

	$obj->debug(10,"new $obj->{'name'}");

	return $obj;
}
# Isconf::File::Item::new
####################################################################################

####################################################################################
# Isconf::File::Item::newvar

=item newvar

	Creates a new variable attached to the object.  Sets it into a
	'vars' hash, and pushes it into a 'varary' array, for ordering.

=cut

sub newvar
{
	my $obj = shift;
	$obj->debug(8,"newvar: $_[0]");
	$obj->debug(8,"newvar: old varhash ", join (" ", $obj->vars() ) );

	my ($var,$value,$newref,$oldref);

	($var,$value) = @_;
	$newref = Isconf::File::Variable->new($var => $value);
	$obj->debug(8,"newvar: newref $newref var $var value $value");

	unless ($oldref = $obj->vars($newref->name()))
	{
		$obj->debug(8,"newvar: adding $var ($value) to varlist");
		$obj->{'vars'}->{'hash'}->{$newref->name()} = $newref;
		push @{ $obj->{'vars'}->{'ary'} }, $newref;
	}
	else
	{
		$oldref->value( $newref->value() );
		$newref = $oldref;
		$obj->debug(8,"newvar: $var already exists");
	}
	$obj->debug(8,"newvar: new varhash ", join (" ", $obj->vars() ) );
	return $newref;
}
# Isconf::File::Item::newvar
####################################################################################

####################################################################################
# Isconf::File::Item::print
sub print
{
	my $obj = shift;
	my ($string,$var,%args,$name,$varref);
	$obj->debug(10,'print');

	if (@_)
	{
		%args = @_;
	}

	if (exists $args{'skipvar'})
	{
		$obj->debug(6,"skipvar is " . join (" " , @{ $args{'skipvar'} }));
	}

	$string = $obj->name();
	foreach $var ($obj->vars())
	{
		$varref = $obj->vars($var);
		$obj->debug(6,"print: var $var ref $varref");
		unless (exists $args{'skipvar'} and 
			grep { $_ eq $varref->name() } @{ $args{'skipvar'} })
		{
			$obj->debug(6,"print: setting", $varref->name() );
			$string .= " " . $varref->print;
		}
		else
		{
			$obj->debug(6,"print: skipping", $varref->name() );
			$obj->debug(6,"print: skipping", $varref->name() );
		}
	}

	if (exists $obj->{'comment'} and $obj->{'comment'})
	{
		$string .= " " . $obj->{'comment'}->print;
	}

	return $string;
}
# Isconf::File::Item::print
####################################################################################

####################################################################################
# Isconf::File::Item::timestamp
sub timestamp
{
	my $obj = shift;
	$obj->debug(6,'timestamp');
	my ($stamp,$tsref);
	if ($stamp = shift)
	{
		$obj->debug(6,"timestamp: setting stamp to $stamp");
		$tsref = $obj->newvar( 'TS'	=> $stamp);
	}

	unless ($tsref = $obj->vars('TS'))
	{
		$obj->debug(6,"timestamp: creating new stamp");
		if ($::STAMP)
		{
			$::STAMP++;
		}
		else
		{
			$obj->debug(6,"timestamp: initializing \$::STAMP");
			my $format = '%Y%m%d%H%M%S';
			my $date = qx|date +$format|;
			chomp $date;
			$::STAMP = $date . "00";
		}
		$tsref = $obj->newvar( 'TS'	=> $::STAMP);
	}
	return $tsref->value();
}
# Isconf::File::Item::timestamp
####################################################################################

####################################################################################
# Isconf::File::Item::vars

=item vars

	Accepts a single argument, the name of a variable.  If passed an
	argument, returns a reference to a variable, if it exists, or
	returns nothing.  If passed nothing, returns a list of existing
	variables, if any.  All returns are Isconf::File::Variable objects.

	Just calls Isconf::lists, because it's such a heavily used type of
	routine.

=cut

sub vars
{
	my $obj = shift;
	$obj->debug(6,'vars');
	return $obj->lists('vars',@_);
}
# Isconf::File::Item::vars
####################################################################################

=head1 NAME

   Isconf::File - stuff

=head1 SYNOPSIS

   Isconf::File

=head1 DESCRIPTION

B<Isconf::File> 

=head1 OPTIONS

=over 4

=item dummy

	E

=back

B<Example>

	Isconf::File

=head1 BUGS

There shouldn't be any...

=head1 SEE ALSO

L<Isconf>,
L<Isconf::File>,

=head1 AUTHOR

Luke A. Kanies, luke.kanies@cat.com

=for html <hr>

I<$Id: Item.pm,v 1.3 2003/07/24 23:56:07 loosifer Exp $>

=cut

1;
