package Isconf::File::Stanza;
#-----------------------------------------------------------------------------------
#
# Isconf::File::Stanza
#
#-----------------------------------------------------------------------------------

use Isconf;
use Isconf::File;
use Exporter;

use vars qw($VERSION @ISA);

@ISA = qw(Isconf Isconf::File);

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::new
sub new
{
	my ($class,%args,$obj,$var,$type);
	($class,%args) = @_;
	$obj = bless {}, $class;

	# we can have 'prereqs', 'items', 'name', and 'vars'
	# but we shouldn't have any null lists....

	unless ($args{'name'}) {
		die "Attempted to create a stanza with no name\n";
	}

	$obj->name($args{'name'});
	$::DEBUG && $obj->debug(10,"new $obj->{'name'}");

	# take care of prerequisites
	if (exists $args{'prereqs'})
	{
		$obj->prereqs(@{$args{'prereqs'}});
	}

	if (exists $args{'itemsorvars'})
	{
		$obj->{'itemsorvars'} = $args{'itemsorvars'};
	}
	# now for items or vars

	foreach my $object (@{ $obj->{'itemsorvars'} })
	{
		my $ref = ref $object;
		my $term;
		for ($ref)
		{
			/Variable/ and do
			{
				$term = 'vars';
			};
			/Item/ and do
			{
				$term = 'items';
			};
		}
		$obj->{$term}->{'hash'}->{$object->name()} = $object;
	}

	#foreach my $term qw(items vars) {
	#	next unless (exists $args{$term});
#
#		foreach $ref (@{ $args{$term} }) {
#			$obj->{$term}->{'hash'}->{$ref->name()} = $ref;
#			# i don't think this is necessary anymore...
#			push @{ $obj->{$term}->{'ary'} }, $ref;
#		}
#	}

	return $obj;
}
# Isconf::File::Stanza::new
#-----------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::print
sub print
{
	my $obj = shift;
	my ($string,$var,%args,$name,$type);
	$::DEBUG && $obj->debug(10,'print');

	# get the header
	$string = join (" ", $obj->names()) . ": " . join(" ", $obj->prereqs()) . "\n";

	# and then all of the other items
	foreach $var (@{ $obj->{'itemsorvars'} })
	{
		$string .= "\t" . $var->print(@_) . "\n";
	}

	return $string;
}
# Isconf::File::Stanza::print
#-----------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::names
sub names
{
	my $obj = shift;
	$::DEBUG && $obj->debug(6,"names");
	if (@_)
	{
		$obj->{'names'} = [ @_ ];
	}
	if ($obj->{'names'})
	{
		return @{ $obj->{'names'} };
	}
	else
	{
		die "No names set for ", $obj->name(), "\n";
	}
}
# Isconf::File::Stanza::names
#-----------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::items
sub items
{
	my $obj = shift;
	$::DEBUG && $obj->debug(6,"items");
	return $obj->lists('items',@_);
}
# Isconf::File::Stanza::targets
#-----------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::vars
sub vars
{
	my $obj = shift;
	$::DEBUG && $obj->debug(6,"vars");
	return $obj->lists('vars',@_);
}
# Isconf::File::Stanza::targets
#-----------------------------------------------------------------------------------

#-----------------------------------------------------------------------------------
# Isconf::File::Stanza::prereqs
sub prereqs
{
	my $obj = shift;

	if (@_)
	{
		if (ref $_[0] eq 'ARRAY')
		{
			$obj->{'prereq'} = shift;
		}
		else
		{
			$obj->{'prereq'} = \@_;
		}
	}

	if (exists $obj->{'prereq'})
	{
		if (wantarray)
		{
			return @{ $obj->{'prereq'} };
		}
		else
		{
			return $obj->{'prereq'};
		}
	}
	else
	{
		return;
	}
}
# Isconf::File::Stanza::prereqs
#-----------------------------------------------------------------------------------

=head1 NAME

   Isconf::File - stuff

=head1 SYNOPSIS

   Isconf::File

=head1 DESCRIPTION

B<Isconf::File> 

=head1 OPTIONS

=over 4

=item dummy

	E

=back

B<Example>

	Isconf::File

=head1 BUGS

There shouldn't be any...

=head1 SEE ALSO

L<Isconf>,
L<Isconf::File>,

=head1 AUTHOR

Luke A. Kanies, luke.kanies@cat.com

=for html <hr>

I<$Id: Stanza.pm,v 1.3 2003/07/24 23:56:07 loosifer Exp $>

=cut
1;
