package Isconf::File::Target;
####################################################################################
####################################################################################
# Isconf::File::Target
####################################################################################
####################################################################################

use Isconf;
use Isconf::File;
use Exporter;

use vars qw($VERSION @ISA);

@ISA = qw(Isconf Isconf::File);

####################################################################################
# Isconf::File::Target::new
sub new
{
	my ($class,%args,$obj,$var,$type);
	($class,%args) = @_;
	$obj = bless {}, $class;

	$obj->{'targethead'} = $args{'targethead'};
	$obj->{'itemsorvars'} = $args{'itemsorvars'};

	if ($obj->{'targethead'}->prereqs() )
	{
		$obj->prereqs($obj->{'targethead'}->prereqs() );
	}

	$obj->name($obj->{'targethead'}->name());

	$obj->debug(10,"new $obj->{'name'}");

	foreach $var (@{ $args{'itemsorvars'} })
	{
		$type = ref $var;
		if ($type =~ /Item/)
		{
			$obj->{'items'}->{'hash'}->{$var->name()} = $var;
			push @{ $obj->{'items'}->{'ary'} }, $var;
		}
		elsif ($type =~ /Variable/)
		{
			$obj->{'vars'}->{'hash'}->{$var->name()} = $var;
			push @{ $obj->{'vars'}->{'ary'} }, $var;
		}
	}

	return $obj;
}
# Isconf::File::Target::new
####################################################################################

####################################################################################
# Isconf::File::Target::print
sub print
{
	my $obj = shift;
	my ($string,$var,%args,$name,$type);
	$obj->debug(10,'print');

	$string = $obj->{'targethead'}->print(@_);
	foreach $var (@{ $obj->{'itemsorvars'} })
	{
		$string .= "\t" . $var->print(@_) . "\n";
	}

	return $string;
}
# Isconf::File::Target::print
####################################################################################

####################################################################################
# Isconf::File::Target::items
sub items
{
	my $obj = shift;
	$obj->debug(6,"items");
	return $obj->lists('items',@_);
}
# Isconf::File::Target::targets
####################################################################################

####################################################################################
# Isconf::File::Target::vars
sub vars
{
	my $obj = shift;
	$obj->debug(6,"vars");
	return $obj->lists('vars',@_);
}
# Isconf::File::Target::targets
####################################################################################

=begin comment
####################################################################################
# Isconf::File::Target::prereqs
sub prereqs
{
	my $obj = shift;

	if (@_)
	{
		if (ref $_[0] eq 'ARRAY')
		{
			$obj->{'prereq'} = shift;
		}
		else
		{
			$obj->{'prereq'} = \@_;
		}
	}

	if (exists $obj->{'prereq'})
	{
		if (wantarray)
		{
			return @{ $obj->{'prereq'} };
		}
		else
		{
			return $obj->{'prereq'};
		}
	}
	else
	{
		return;
	}
}
# Isconf::File::Target::prereqs
####################################################################################
=cut

=head1 NAME

   Isconf::File - stuff

=head1 SYNOPSIS

   Isconf::File

=head1 DESCRIPTION

B<Isconf::File> 

=head1 OPTIONS

=over 4

=item dummy

	E

=back

B<Example>

	Isconf::File

=head1 BUGS

There shouldn't be any...

=head1 SEE ALSO

L<Isconf>,
L<Isconf::File>,

=head1 AUTHOR

Luke A. Kanies, luke.kanies@cat.com

=for html <hr>

I<$Id: Target.pm,v 1.3 2003/07/24 23:56:07 loosifer Exp $>

=cut
1;
