package Isconf::Parse;

BEGIN {
	push @INC, "/home/kaniela/cvs/code/local-perl";
}
#-----------------------------------------------------------------------------------
#
# Isconf::Parse
#
#-----------------------------------------------------------------------------------

use vars qw(@ISA $VERSION);

@ISA = qw(Isconf);
use Parse::Lex;
use FileHandle;

use Isconf::File::Blank;
use Isconf::File::Comment;
use Isconf::File::Item;
use Isconf::Parser;
use Isconf::File::Stanza;
use Isconf::File::Variable;

# these are global because Parse::Lex defaines the terms as global,
# so otherwise these get redefined and i get warnings
# yuck
use vars qw(@LEXGRAMMAR $LEXER);

# I choose this quoting method so i can see the code
@LEXGRAMMAR = (
	'COMMENT', '(?<!\\$)#.*$',
	'RETURN', '\n',
	'TAB', '\t',
	'COLON', ':',
	'EQUALS', '=',
	'NAME', '[-\w\/.\${}]+',
	'DQSTRING', [ '"', '[^"]*', '"' ], sub {
			my ($token, $string) = @_;
			$string =~ s/^"//;
			$string =~ s/"$//;
			return $string;
	},
	'SQSTRING', [ "'", "[^']*", "'" ], sub {
			my ($token, $string) = @_;
			$string =~ s/^'//;
			$string =~ s/'$//;
			return $string;
	},
	'STRING', '\S+',
	'ERROR', '(?s:.*)',
		sub {
			my $line = $_[0]->line();
			die "line $line: syntax error: \"$_[1]\"\n";
		}
);

unless ($LEXER)
{
	$LEXER = Parse::Lex->new(@LEXGRAMMAR) or
		die "Could not make lexer\n";
}

#------------------------------------------------------------------------
# _lexer
sub _lexer
{
   my ($parser) = @_;
	my ($token, $lexer);

	$lexer = $parser->YYData->{'lexer'};
#	print "lexer = $lexer\n";

	while (1)
	{
		$token = $lexer->next;

		if ($lexer->eoi)
		{
#			print "lexer returning EOI\n";
			return ('', undef);
		}

		next if ($token->name eq 'COMMENT');

#		print "lexer returning (" . $token->name . ", \"" . $token->text . "\")\n";
		return ($token->name, $token->text);
	}
}
# _lexer
#------------------------------------------------------------------------

#------------------------------------------------------------------------
# _error
sub _error
{
	my ($parser) = @_;
	my ($config, $lexer, $file, $line);

	$file = $parser->YYData->{'file'};

	$lexer = $parser->YYData->{'lexer'};
	$line = $lexer->line;

	die("$file:$line: parse error\n");
}
# _error
#------------------------------------------------------------------------

#------------------------------------------------------------------------
# Isconf::Parse::parse
sub parse
{
	my ($class,$obj,$objlist,$ref,$file,@lines,$comment,$refclass);

	$file = shift;

	my $typehandle = new FileHandle $file, "r" or
		die "Could not open $file: $!\n";

	#open TYPES, $file or die "Could not open $file: $!\n";
	#@lines = <TYPES>;
	#close TYPES;

	$LEXER ||= Parse::Lex->new(@LEXGRAMMAR) or
		die "Could not make lexer\n";

	$LEXER->from($typehandle);
	$LEXER->configure('Skip' => ' +');
	my $parser = Isconf::Parser->new();
	$parser->YYData->{'lexer'} = $LEXER;
	$parser->YYData->{'file'} = $file;

	$parser->YYParse(yylex => \&_lexer,
		#yydebug => 0x1F,
		yyerror => \&_error
	);

	$typehandle->close();

	if (wantarray)
	{
		return @{ $parser->YYData->{'objects'} };
	}
	else
	{
		return $parser->YYData->{'objects'};
	}
}
# Isconf::Parse::parse
#-----------------------------------------------------------------------------------

=head1 NAME

   Isconf::Parse - Modules for parsing Isconf 3l config files

=head1 SYNOPSIS

   Isconf::Parse

=head1 DESCRIPTION

B<Isconf::Parse>

=head1 OPTIONS

=over 4


=item dummy

	E

=back

=head1 SEE ALSO

L<Cat>,
L<Isconf>

=head1 AUTHOR

Luke A. Kanies, luke.kanies@cat.com

=for html <hr>

I<$Id: Parse.pm,v 1.3 2003/07/24 23:56:07 loosifer Exp $>

=cut
1;
